#!/bin/sh
#
# Licensed Material of Hitachi, Ltd.
# Reproduction, use, modification or disclosure otherwise than
# permitted in the License Agreement is strictly prohibited.
#
# All Rights Reserved. Copyright (C) 2012, 2016, Hitachi, Ltd.
#

PRODUCT="hsnvcm"
VERSION="0790-00"

RPM_OPT=$1
SETUPSHPATH=$(cd $(dirname $0); pwd)
SNVAM_LOGPATH=/var/log/snvam
SNVAM_LOGFILE=${SNVAM_LOGPATH}/snvam_setup.log

#--------------------------------------------
# log to file.
#--------------------------------------------
function do_putlog() {
    NOW=`date +"%Y/%d/%m %T"`
    echo "${NOW}: $@" >> ${SNVAM_LOGFILE} 2>/dev/null
}

#--------------------------------------------
# log & stdout.
#--------------------------------------------
function do_stdout() {
	do_putlog $@
	echo $@
}

if [ ! -d ${SNVAM_LOGPATH} ]; then
    mkdir ${SNVAM_LOGPATH}
fi
do_putlog "*** Connector for Manager setup start. (mode='$@')"

#--------------------------------------------
# Install rpm package.
#--------------------------------------------
function do_install() {
	if [ ${#1} -ne 0 ]; then
		PKGFILE="${PRODUCT}-${VERSION}.$1.${CPU_ARCH}.rpm"
	else
		PKGFILE="${PRODUCT}-${VERSION}.${CPU_ARCH}.rpm"
	fi
	RPMPKG="${SETUPSHPATH}/$2/${PKGFILE}"
    rpm ${RPM_OPT} ${RPMPKG} 2> ${SNVAM_LOGPATH}/snvcm_error.log
    if [ $? -eq 0 ]; then
        do_putlog "${PKGFILE} was installed."
    else
        do_stdout "${PKGFILE} install failed."
        do_stdout "`cat ${SNVAM_LOGPATH}/snvcm_error.log`"
		exit 1
    fi
	rm -f ${SNVAM_LOGPATH}/snvcm_error.log
}

#--------------------------------------------
# Get CPU arch.
#--------------------------------------------
uname -i | grep -q "x86_64"
if [ $? -eq 0 ]; then
    CPU_ARCH="x86_64"
else
    CPU_ARCH="i386"
fi

RHEL_RELEASE=/etc/redhat-release
VMA_RELEASE=/etc/vma-release
#--------------------------------------------
# Get platform type.
#   INSTALLED_OS_TYPE=0   : Guest RHEL
#   INSTALLED_OS_TYPE=1   : Real  RHEL
#   INSTALLED_OS_TYPE=2   : vMA
#   INSTALLED_OS_TYPE=100 : Other (SuSE...)
#--------------------------------------------
INSTALLED_OS_TYPE=100
which virt-what > /dev/null 2>&1
if [ $? -eq 0 ]; then
    INSTALLED_OS_TYPE=1
    VMACHINE=`virt-what`
    if [ ${#VMACHINE} -ne 0 ]; then
        do_putlog "virt-what: ${VMACHINE}"
        if [ $VMACHINE = "vmware" ]; then
            INSTALLED_OS_TYPE=0
        fi
    fi
else
	if [ -e ${VMA_RELEASE} ]; then
		INSTALLED_OS_TYPE=2
	fi
fi

# for force install to RHEL on VMware Player.
if [ $# -eq 2 ]; then
	if [ $2 = "-force" ]; then
    	INSTALLED_OS_TYPE=1
	fi
fi

do_putlog "INSTALLED_OS_TYPE=${INSTALLED_OS_TYPE}"

rpm -q "${PRODUCT}-0740-00" --quiet
CURPACKVER=$?

if [ ${RPM_OPT} = "-e" ]; then
    rpm ${RPM_OPT} ${PRODUCT} --allmatches 2> ${SNVAM_LOGPATH}/snvcm_error.log
	if [ $? -eq 0 ]; then
    	do_putlog "${PRODUCT} was uninstalled."
	else
		do_stdout "`cat ${SNVAM_LOGPATH}/snvcm_error.log`"
		exit 1
	fi
else
    if [ -e ${RHEL_RELEASE} -a ${INSTALLED_OS_TYPE} -eq 0 ]; then
		do_install "vel" "velrpms"
    elif [ -e ${RHEL_RELEASE} -a ${INSTALLED_OS_TYPE} -eq 1 ]; then
		do_install "el" "elrpms"
    elif [ ${INSTALLED_OS_TYPE} -eq 2 ]; then
		do_install "" "rpms"
    else
        do_stdout "This OS is not supported. "
        exit 1
    fi
	do_putlog "`ls -lR /opt/hitachi/snv-cm`"
fi

if [ ${CURPACKVER} -eq 0 ]; then
	do_putlog "/opt/hitachi/snv-cm was overwritten by snv-cm-temporary"
    mv -f /opt/hitachi/snv-cm-temporary/ /opt/hitachi/snv-cm/ > /dev/null 2>&1
fi

